@@ -7,7 +7,7 @@ import os
 import re
 import time
 import traceback
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, date
 from urllib import parse
 
 import quasarr
@@ -23,6 +23,21 @@ lock = None
 SEASON_EP_REGEX = re.compile(r"(?i)(?:S\d{1,3}(?:E\d{1,3}(?:-\d{1,3})?)?|S\d{1,3}-\d{1,3})")
 # regex to filter out season/episode tags for movies
 MOVIE_REGEX = re.compile(r"^(?!.*(?:S\d{1,3}(?:E\d{1,3}(?:-\d{1,3})?)?|S\d{1,3}-\d{1,3})).*$", re.IGNORECASE)
+# List of known file hosters that should not be used as search/feed sites
+SHARE_HOSTERS = {
+    "rapidgator",
+    "ddownload",
+    "keep2share",
+    "1fichier",
+    "katfile",
+    "filer",
+    "turbobit",
+    "nitroflare",
+    "filefactory",
+    "uptobox",
+    "mediafire",
+    "mega",
+}
 
 
 def set_state(manager_dict, manager_lock):
@@ -63,26 +78,37 @@ def generate_api_key():
 
 
 def extract_valid_hostname(url, shorthand):
-    # Check if both characters from the shorthand appear in the url
     try:
         if '://' not in url:
             url = 'http://' + url
         result = parse.urlparse(url)
         domain = result.netloc
+        parts = domain.split('.')
 
-        if not "." in domain:
-            print(f'Invalid domain "{domain}": No "." found')
-            return None
+        if domain.startswith(".") or domain.endswith(".") or "." not in domain[1:-1]:
+            message = f'Error: "{domain}" must contain a "." somewhere in the middle – you need to provide a full domain name!'
+            domain = None
+
+        elif any(hoster in parts for hoster in SHARE_HOSTERS):
+            offending = next(host for host in parts if host in SHARE_HOSTERS)
+            message = (
+                f'Error: "{domain}" is a file‑hosting domain and cannot be used here directly! '
+                f'Instead please provide a valid hostname that serves direct file links (including "{offending}").'
+            )
+            domain = None
+
+        elif all(char in domain for char in shorthand):
+            message = f'"{domain}" contains both characters from shorthand "{shorthand}". Continuing...'
 
-        if all(char in domain for char in shorthand):
-            print(f'"{domain}" matches both characters from "{shorthand}". Continuing...')
-            return domain
         else:
-            print(f'Invalid domain "{domain}": Does not contain both characters from shorthand "{shorthand}"')
-            return None
+            message = f'Error: "{domain}" does not contain both characters from shorthand "{shorthand}".'
+            domain = None
     except Exception as e:
-        print(f"Error parsing URL {url}: {e}")
-        return None
+        message = f"Error: {e}. Please provide a valid URL."
+        domain = None
+
+    print(message)
+    return {"domain": domain, "message": message}
 
 
 def connect_to_jd(jd, user, password, device_name):
@@ -320,7 +346,7 @@ def set_device_settings():
                  'filenameFilter': {
                      'enabled': True,
                      'matchType': 'CONTAINS',
-                     'regex': '.*\\.(sfv|jpe?g|idx|sub|srt|nfo|bat|txt|exe)',
+                     'regex': '.*\\.(sfv|jpe?g|idx|srt|nfo|bat|txt|exe)',
                      'useRegex': True
                  },
                  'filesizeFilter': {'enabled': False, 'from': 0, 'matchType': 'BETWEEN', 'to': 0},
@@ -428,12 +454,39 @@ def convert_to_mb(item):
     return int(size_mb)
 
 
+def sanitize_title(title: str) -> str:
+    umlaut_map = {
+        "Ä": "Ae", "ä": "ae",
+        "Ö": "Oe", "ö": "oe",
+        "Ü": "Ue", "ü": "ue",
+        "ß": "ss"
+    }
+    for umlaut, replacement in umlaut_map.items():
+        title = title.replace(umlaut, replacement)
+
+    title = title.encode("ascii", errors="ignore").decode()
+
+    # Replace slashes and spaces with dots
+    title = title.replace("/", "").replace(" ", ".")
+    title = title.strip(".")  # no leading/trailing dots
+    title = title.replace(".-.", "-")  # .-. → -
+
+    # Finally, drop any chars except letters, digits, dots, hyphens, ampersands
+    title = re.sub(r"[^A-Za-z0-9.\-&]", "", title)
+
+    # remove any repeated dots
+    title = re.sub(r"\.{2,}", ".", title)
+    return title
+
+
 def sanitize_string(s):
     s = s.lower()
 
     # Remove dots / pluses
     s = s.replace('.', ' ')
     s = s.replace('+', ' ')
+    s = s.replace('_', ' ')
+    s = s.replace('-', ' ')
 
     # Umlauts
     s = re.sub(r'ä', 'ae', s)
@@ -543,16 +596,18 @@ def is_valid_release(title: str,
     - episode: desired episode number (or None)
     """
     try:
-        # if search string is NOT an imdb id check search_string_in_sanitized_title - if not match, its not valid
-        if not is_imdb_id(search_string):
-            if not search_string_in_sanitized_title(search_string, title):
-                debug(f"Skipping {title!r} as it doesn't match sanitized search string: {search_string!r}")
-                return False
-
         # Determine whether this is a movie or TV search
         rf = request_from.lower()
         is_movie_search = 'radarr' in rf
         is_tv_search = 'sonarr' in rf
+        is_docs_search = 'lazylibrarian' in rf
+
+        # if search string is NOT an imdb id check search_string_in_sanitized_title - if not match, its not valid
+        if not is_docs_search and not is_imdb_id(search_string):
+            if not search_string_in_sanitized_title(search_string, title):
+                debug(f"Skipping {title!r} as it doesn't match sanitized search string: {search_string!r}")
+                return False
+
 
         # if it's a movie search, don't allow any TV show titles (check for NO season or episode tags in the title)
         if is_movie_search:
@@ -574,6 +629,14 @@ def is_valid_release(title: str,
                     return False
             return True
 
+        # if it's a document search, it should not contain Movie or TV show tags
+        if is_docs_search:
+            # must NOT have any S/E tag present
+            if SEASON_EP_REGEX.search(title):
+                debug(f"Skipping {title!r} as title matches TV show regex: {SEASON_EP_REGEX.pattern}")
+                return False
+            return True
+
         # unknown search source — reject by default
         debug(f"Skipping {title!r} as search source is unknown: {request_from!r}")
         return False
@@ -588,12 +651,159 @@ def is_valid_release(title: str,
         return False
 
 
+def normalize_magazine_title(title: str) -> str:
+    """
+    Massage magazine titles so LazyLibrarian's parser can pick up dates reliably:
+    - Convert date-like patterns into space-delimited numeric tokens (YYYY MM DD or YYYY MM).
+    - Handle malformed "DD.YYYY.YYYY" cases (e.g., 04.2006.2025 → 2025 06 04).
+    - Convert two-part month-year like "3.25" into YYYY MM.
+    - Convert "No/Nr/Sonderheft X.YYYY" when X≤12 into YYYY MM.
+    - Preserve pure issue/volume prefixes and other digit runs untouched.
+    """
+    title = title.strip()
+
+    # 0) Bug: DD.YYYY.YYYY -> treat second YYYY's last two digits as month
+    def repl_bug(match):
+        d = int(match.group(1))
+        m_hint = match.group(2)
+        y = int(match.group(3))
+        m = int(m_hint[-2:])
+        try:
+            date(y, m, d)
+            return f"{y:04d} {m:02d} {d:02d}"
+        except ValueError:
+            return match.group(0)
+
+    title = re.sub(r"\b(\d{1,2})\.(20\d{2})\.(20\d{2})\b", repl_bug, title)
+
+    # 1) DD.MM.YYYY -> "YYYY MM DD"
+    def repl_dmy(match):
+        d, m, y = map(int, match.groups())
+        try:
+            date(y, m, d)
+            return f"{y:04d} {m:02d} {d:02d}"
+        except ValueError:
+            return match.group(0)
+
+    title = re.sub(r"\b(\d{1,2})\.(\d{1,2})\.(\d{4})\b", repl_dmy, title)
+
+    # 2) DD[.]? MonthName YYYY (optional 'vom') -> "YYYY MM DD"
+    def repl_dmony(match):
+        d = int(match.group(1))
+        name = match.group(2)
+        y = int(match.group(3))
+        mm = _month_num(name)
+        if mm:
+            try:
+                date(y, mm, d)
+                return f"{y:04d} {mm:02d} {d:02d}"
+            except ValueError:
+                pass
+        return match.group(0)
+
+    title = re.sub(
+        r"\b(?:vom\s*)?(\d{1,2})\.?\s+([A-Za-zÄÖÜäöüß]+)\s+(\d{4})\b",
+        repl_dmony,
+        title,
+        flags=re.IGNORECASE
+    )
+
+    # 3) MonthName YYYY -> "YYYY MM"
+    def repl_mony(match):
+        name = match.group(1)
+        y = int(match.group(2))
+        mm = _month_num(name)
+        if mm:
+            try:
+                date(y, mm, 1)
+                return f"{y:04d} {mm:02d}"
+            except ValueError:
+                pass
+        return match.group(0)
+
+    title = re.sub(r"\b([A-Za-zÄÖÜäöüß]+)\s+(\d{4})\b", repl_mony, title, flags=re.IGNORECASE)
+
+    # 4) YYYYMMDD -> "YYYY MM DD"
+    def repl_ymd(match):
+        y = int(match.group(1))
+        m = int(match.group(2))
+        d = int(match.group(3))
+        try:
+            date(y, m, d)
+            return f"{y:04d} {m:02d} {d:02d}"
+        except ValueError:
+            return match.group(0)
+
+    title = re.sub(r"\b(20\d{2})(0[1-9]|1[0-2])(0[1-9]|[12]\d|3[01])\b", repl_ymd, title)
+
+    # 5) YYYYMM -> "YYYY MM"
+    def repl_ym(match):
+        y = int(match.group(1))
+        m = int(match.group(2))
+        try:
+            date(y, m, 1)
+            return f"{y:04d} {m:02d}"
+        except ValueError:
+            return match.group(0)
+
+    title = re.sub(r"\b(20\d{2})(0[1-9]|1[0-2])\b", repl_ym, title)
+
+    # 6) X.YY (month.two-digit-year) -> "YYYY MM" (e.g., 3.25 -> 2025 03)
+    def repl_my2(match):
+        mm = int(match.group(1))
+        yy = int(match.group(2))
+        y = 2000 + yy
+        if 1 <= mm <= 12:
+            try:
+                date(y, mm, 1)
+                return f"{y:04d} {mm:02d}"
+            except ValueError:
+                pass
+        return match.group(0)
+
+    title = re.sub(r"\b([1-9]|1[0-2])\.(\d{2})\b", repl_my2, title)
+
+    # 7) No/Nr/Sonderheft <1-12>.<YYYY> -> "YYYY MM"
+    def repl_nmy(match):
+        num = int(match.group(1))
+        y = int(match.group(2))
+        if 1 <= num <= 12:
+            try:
+                date(y, num, 1)
+                return f"{y:04d} {num:02d}"
+            except ValueError:
+                pass
+        return match.group(0)
+
+    title = re.sub(
+        r"\b(?:No|Nr|Sonderheft)\s*(\d{1,2})\.(\d{4})\b",
+        repl_nmy,
+        title,
+        flags=re.IGNORECASE
+    )
+
+    return title
+
+
+# Helper for month name mapping
+def _month_num(name: str) -> int:
+    name = name.lower()
+    mmap = {
+        'januar': 1, 'jan': 1, 'februar': 2, 'feb': 2, 'märz': 3, 'maerz': 3, 'mär': 3, 'mrz': 3, 'mae': 3,
+        'april': 4, 'apr': 4, 'mai': 5, 'juni': 6, 'jun': 6, 'juli': 7, 'jul': 7, 'august': 8, 'aug': 8,
+        'september': 9, 'sep': 9, 'oktober': 10, 'okt': 10, 'november': 11, 'nov': 11, 'dezember': 12, 'dez': 12,
+        'january': 1, 'february': 2, 'march': 3, 'april': 4, 'may': 5, 'june': 6, 'july': 7, 'august': 8,
+        'september': 9, 'october': 10, 'november': 11, 'december': 12
+    }
+    return mmap.get(name)
+
+
 def get_recently_searched(shared_state, context, timeout_seconds):
     recently_searched = shared_state.values.get(context, {})
     threshold = datetime.now() - timedelta(seconds=timeout_seconds)
     keys_to_remove = [key for key, value in recently_searched.items() if value["timestamp"] <= threshold]
     for key in keys_to_remove:
-        debug(f"Removing '/{key}' from recently searched memory ({context})...")
+        debug(f"Removing '{key}' from recently searched memory ({context})...")
         del recently_searched[key]
     return recently_searched
 
